/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id$ */

package org.apache.fop.apps.io;

import java.net.URI;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

import org.apache.xmlgraphics.io.ResourceResolver;

abstract class TestingResourceResolver implements ResourceResolver {

    private final Map<URI, Object> checker;

    TestingResourceResolver() {
        checker = new HashMap<URI, Object>();
    }

    void recordProperty(URI uri, Object obj) {
        checker.put(uri, obj);
    }

    Map<URI, Object> getMap() {
        return Collections.unmodifiableMap(checker);
    }

}
